@@ -1,4 +1,5 @@
 """Main implementation of Modular CMA-ES."""
+from inspect import Parameter
 import os
 from itertools import islice
 from typing import List, Callable
@@ -82,22 +83,27 @@ class ModularCMAES:
 
         y = np.dot(self.parameters.B, self.parameters.D * z)
         x = self.parameters.m + (s * y)
-        x, n_out_of_bounds = correct_bounds(x, 
+        x, n_out_of_bounds = correct_bounds(
+            x, 
             self.parameters.ub,
             self.parameters.lb,
             self.parameters.bound_correction
         )
         self.parameters.n_out_of_bounds += n_out_of_bounds
-
-        f = np.empty(n_offspring, object)
-        for i in range(n_offspring):
-            f[i] = self.fitness_func(x[:, i])
-            if self.sequential_break_conditions(i, f[i]):
-                f = f[:i]
-                s = s[:i]
-                x = x[:, :i]
-                y = y[:, :i]
-                break
+        
+        if not self.parameters.sequential and self.parameters.vectorized_fitness:
+            f = self._fitness_func(x.T)
+            self.parameters.used_budget += len(x.T)       
+        else:
+            f = np.empty(n_offspring, object)
+            for i in range(n_offspring):
+                f[i] = self.fitness_func(x[:, i])
+                if self.sequential_break_conditions(i, f[i]):
+                    f = f[:i]
+                    s = s[:i]
+                    x = x[:, :i]
+                    y = y[:, :i]
+                    break
 
         if perform_tpa:
             yt, xt, ft = tpa_mutation(self.fitness_func, self.parameters)
@@ -375,7 +381,7 @@ def correct_bounds(
     """
     out_of_bounds = np.logical_or(x > ub, x < lb)
     n_out_of_bounds = out_of_bounds.max(axis=0).sum()
-    if n_out_of_bounds == 0 or correction_method == None:
+    if n_out_of_bounds == 0 or correction_method is None:
         return x, n_out_of_bounds
 
     try:
@@ -456,19 +462,19 @@ def evaluate_bbob(
     """
     # This speeds up the import, this import is quite slow, so import it lazy here
     # pylint: disable=import-outside-toplevel
-    from IOHexperimenter import IOH_function, IOH_logger
+    import ioh
 
     evals, fopts = np.array([]), np.array([])
     if seed:
         np.random.seed(seed)
-    fitness_func = IOH_function(
-        fid, dim, instance, target_precision=target_precision, suite="BBOB"
+    fitness_func = ioh.get_problem(
+        fid, dimension=dim, instance=instance
     )
-    
+
     if logging:
         data_location = data_folder if os.path.isdir(data_folder) else os.getcwd()
-        logger = IOH_logger(data_location, f"{label}F{fid}_{dim}D")
-        fitness_func.add_logger(logger)
+        logger = ioh.logger.Analyzer(root=data_location, folder_name=f"{label}F{fid}_{dim}D")
+        fitness_func.attach_logger(logger)
 
     print(
         f"Optimizing function {fid} in {dim}D for target "
@@ -478,11 +484,11 @@ def evaluate_bbob(
     for idx in range(iterations):
         if idx > 0:
             fitness_func.reset()
-        target = fitness_func.get_target()
+        target = fitness_func.objective.y + target_precision
 
         optimizer = ModularCMAES(fitness_func, dim, target=target, **kwargs).run()
-        evals = np.append(evals, fitness_func.evaluations)
-        fopts = np.append(fopts, fitness_func.best_so_far_precision)
+        evals = np.append(evals, fitness_func.state.evaluations)
+        fopts = np.append(fopts, fitness_func.state.current_best_internal.y)
 
     result_string = (
         "FCE:\t{:10.8f}\t{:10.4f}\n"
